HashTagText class

Show decorated tagged text only to be shown

decoratedStyle is textStyle of tagged text. basicStyle is textStyle of others. onTap is called when a tagged text is tapped.

Inheritance

Constructors

HashTagText({required String text, required TextStyle basicStyle, required TextStyle decoratedStyle, bool decorateAtSign = false, dynamic onTap(String)?, TextAlign textAlign = TextAlign.start, TextDirection? textDirection, bool softWrap = true, TextOverflow overflow = TextOverflow.clip, double textScaleFactor = 1.0, int? maxLines, Locale? locale, StrutStyle? strutStyle, TextWidthBasis textWidthBasis = TextWidthBasis.parent, TextHeightBehavior? textHeightBehavior})

Properties

basicStyle → TextStyle
final
decorateAtSign → bool
final
decoratedStyle → TextStyle
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → Locale?
final
maxLines → int?
final
onTap → dynamic Function(String)?
final
overflow → TextOverflow
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softWrap → bool
final
strutStyle → StrutStyle?
final
text → String
final
textAlign → TextAlign
final
textDirection → TextDirection?
final
textHeightBehavior → TextHeightBehavior?
final
textScaleFactor → double
final
textWidthBasis → TextWidthBasis
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited